#
# spec file for package python-oslo.vmware
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-oslo.vmware
Version:        4.6.0
Release:        1.1
Summary:        Oslo VMware library for OpenStack projects
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/oslo.vmware
Source0:        https://files.pythonhosted.org/packages/source/o/oslo-vmware/oslo_vmware-4.6.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-Babel
BuildRequires:  python3-ddt
BuildRequires:  python3-defusedxml
BuildRequires:  python3-eventlet >= 0.18.2
BuildRequires:  python3-fixtures
BuildRequires:  python3-lxml >= 4.5.0
BuildRequires:  python3-netaddr >= 0.7.18
BuildRequires:  python3-oslo.concurrency >= 3.26.0
BuildRequires:  python3-oslo.context >= 2.19.2
BuildRequires:  python3-oslo.i18n >= 3.15.3
BuildRequires:  python3-oslo.utils >= 3.33.0
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-python-subunit
BuildRequires:  python3-requests >= 2.14.2
BuildRequires:  python3-stestr
BuildRequires:  python3-suds-community >= 0.6
BuildRequires:  python3-testscenarios
BuildRequires:  python3-testtools
BuildRequires:  python3-urllib3 >= 1.21.1
BuildArch:      noarch

%description
The Oslo project intends to produce a python library containing infrastructure
code shared by OpenStack projects. The APIs provided by the project should be
high quality, stable, consistent and generally useful.

The Oslo VMware library offers session and API call management for VMware ESX/VC
server.

%package -n python3-oslo.vmware
Summary:        Oslo VMware library for OpenStack projects
Requires:       python3-PyYAML >= 3.13
Requires:       python3-defusedxml
Requires:       python3-eventlet >= 0.18.2
Requires:       python3-lxml >= 4.5.0
Requires:       python3-netaddr >= 0.7.18
Requires:       python3-oslo.concurrency >= 3.26.0
Requires:       python3-oslo.context >= 2.19.2
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.utils >= 3.33.0
Requires:       python3-requests >= 2.14.2
Requires:       python3-stevedore >= 1.20.0
Requires:       python3-suds-community >= 0.6
Requires:       python3-urllib3 >= 1.21.1

%description -n python3-oslo.vmware
The Oslo project intends to produce a python library containing infrastructure
code shared by OpenStack projects. The APIs provided by the project should be
high quality, stable, consistent and generally useful.

The Oslo VMware library offers session and API call management for VMware ESX/VC
server.

This package contains the Python 3.x module.

%package        -n python-oslo.vmware-doc
Summary:        Documentation for OpenStack common VMware library
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-sphinxcontrib-apidoc

%description -n python-oslo.vmware-doc
Documentation for OpenStack common VMware library.

%prep
%autosetup -p1 -n oslo_vmware-4.6.0
%py_req_cleanup

%build
%py3_build

# generate html docs
PBR_VERSION=%{version} %sphinx_build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%py3_install

%check
# don't want to depend on hacking for package building
rm oslo_vmware/tests/test_hacking.py
%{openstack_stestr_run}

%files -n python3-oslo.vmware
%doc README.rst
%license LICENSE
%{python3_sitelib}/oslo_vmware
%{python3_sitelib}/*.egg-info

%files -n python-oslo.vmware-doc
%doc doc/build/html
%license LICENSE

%changelog
* Tue Jul  1 2025 Dirk Müller <dmueller@suse.com>
- update to 4.6.0:
  * Skip installation to speed up pep8
  * Run pyupgrade to clean up Python 2 syntaxes
  * Replace deprecated defusedxml.lxml
  * reno: Update master for unmaintained/2023.1
  * pre-commit: Bump versions
  * Add note about requirements lower bounds
  * Remove Python 3.8 support
  * Declare Python 3.12 support
  * Fix wrong tox minversion
  * Update master for stable/2024.2
* Mon Sep  2 2024 cloud-devel@suse.de
- update to version 4.5.0
  - Update master for stable/2024.1
  - reno: Update master for unmaintained/victoria
  - reno: Update master for unmaintained/zed
  - reno: Update master for unmaintained/wallaby
  - reno: Update master for unmaintained/xena
* Thu May  2 2024 cloud-devel@suse.de
- update to version 4.4.0
  - reno: Update master for unmaintained/yoga
  - Update python classifier in setup.cfg
* Thu Jan  4 2024 cloud-devel@suse.de
- update to version 4.3.0
  - Imported Translations from Zanata
  - Moves supported python runtimes from version 3.8 to 3.10
  - Revert "Moves supported python runtimes from version 3.8 to 3.10"
  - Update master for stable/2023.1
  - Update master for stable/2023.2
  - Add PBM WSDL for vSphere 8.0
  - Bump bandit and make oslo.messaging compatible with latest rules
* Mon Mar  6 2023 cloud-devel@suse.de
- update to version 4.1.1
  - Update master for stable/zed
  - Fix issues related to tox4
  - Add Python3 antelope unit tests
  - remove unicode literal from code
* Sat Oct  1 2022 cloud-devel@suse.de
- update to version 4.0.1
  - remove unicode literal from code
  - Drop python3.6/3.7 support in testing runtime
  - Add Python3 zed unit tests
  - Download ISO in more simple way.
  - Fix formatting of release list
  - Update master for stable/yoga
  - Imported Translations from Zanata
* Tue May 24 2022 Dirk Müller <dmueller@suse.com>
- remove unneeded dependencies
* Sat Dec 11 2021 cloud-devel@suse.de
- update to version 3.10.0
  - Add Python3 yoga unit tests
  - Don't use 'requests.PreparedRequest'
  - Update master for stable/xena
  - Replace suds-jurko with suds-community
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 3.9.1
  - Use TOX_CONSTRAINTS_FILE
  - Use py3 as the default runtime for tox
  - Ignore already deleted lease
  - Remove lower-constraints remnants
  - Update master for stable/wallaby
  - Add serialize_object() helper function
  - Add Python3 xena unit tests
  - Move flake8 as a pre-commit local target.
  - setup.cfg: Replace dashes with underscores
* Sun May  2 2021 cloud-devel@suse.de
- update to version 3.8.0
  - Adding pre-commit
  - Add Python3 wallaby unit tests
  - Add PBM WSDL for vSphere 7.0
  - Update master for stable/victoria
  - Imported Translations from Zanata
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 3.7.0
  - Add py38 package metadata
  - Bump default tox env from py37 to py38
  - Switch to newer openstackdocstheme and reno versions
  - Add backend-independent access to cookiejar
  - Add release notes links to doc index
  - Add Python3 victoria unit tests
  - Remove the unused coding style modules
  - Add moref helper functions
  - [goal] Migrate testing to ubuntu focal
  - Remove translation sections from setup.cfg
  - Align contributing doc with oslo's policy
  - Update master for stable/ussuri
  - Fix hacking min version to 3.0.1
  - Imported Translations from Zanata
  - Bump bandit version
  - Validation of VMDK upload completion
* Tue May 12 2020 cloud-devel@suse.de
- update to version 3.3.1
  - Pass "base_image_ref" to backend when transfer volume to image
  - Ensure lease polling raises proper exception
  - Fix object has no attribute 'readinto' in Python3
  - Document disable flake8/hacking warnings
  - [ussuri][goal] Drop python 2.7 support and testing
  - Add ability to change read chunk size
  - Adds standard file operation functions
  - tox: Trivial cleanup
  - Update hacking for Python3
  - remove outdated header
  - Use unittest.mock instead of third party mock
  - Pass "store_id" to backend when transfer volume to image
  - Update the tox minversion parameter.
  - tox: Keeping going with docs
  - reword releasenote for py27 support dropping
  - Switch to Ussuri jobs
  - Drop use of six
  - Update master for stable/train
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only builds
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 2.34.1
  - Add local bindep.txt
  - Dropping the py35 testing
  - Add nosec to skip bandit check
  - OpenDev Migration Patch
  - Replace git.openstack.org URLs with opendev.org URLs
  - Sync Sphinx requirement
  - Set locale to english
  - When looping call fails do not log the exception trace
  - Change python3.5 job to python3.7 job on Stein+
  - Add Python 3 Train unit tests
  - Fix invalid escape sequence warning
  - Ensure that log message with non-ascii code does not raise exception
  - SDRS recommendation for create VM
  - Update master for stable/stein
  - Return None if no suitable datastore is found
  - Follow the new PTI for document build
  - Fix doc build error under Python 3
  - Update NFC lease progress
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 2.32.2
  - Change openstack-dev to openstack-discuss
  - add lib-forward-testing-python3 test job
  - Add DVS utility methods
  - import zuul job settings from project-config
  - Imported Translations from Zanata
  - Update reno for stable/rocky
  - Clean up .gitignore references to personal tools
  - Use template for lower-constraints
  - add python 3.6 unit test job
  - py37: deal with Exception repr changes
  - Check if there is a context set before updating the store
  - add python 3.7 unit test job
  - Set request context when polling vCenter tasks
  - delete useless indent
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 2.31.0
  - Update reno for stable/queens
  - pypy is not checked at gate
  - Switch to stestr
  - Imported Translations from Zanata
  - Add release notes link to README
  - Refactor _start_transfer
  - Fix session re-establish failure with PBM APIs
  - Add function for getting recommended datastore
  - Fix docstring which breaks doc generation
  - Utility method to check SDRS enabled status
  - Remove stale pip-missing-reqs tox test
  - Update links in README
  - PBM WSDL for vSphere 6.7
  - Trivial: Update pypi url to new url
  - set default python to python3
  - fix tox python3 overrides
  - fix lower constraints and uncap eventlet
  - add lower-constraints job
  - fix a typo:s/extention/extension
  - Add traversal spec for datastoreFolder
  - Specify CA store when making secure connections with urllib3
  - Updated from global requirements
  - Add utility function for datastore clusters
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 2.26.0
  - Fix the repeating titles
  - Remove -U from pip install
  - Update reno for stable/pike
  - Remove setting of version/release from releasenotes
  - Imported Translations from Zanata
  - Avoid tox_install.sh for constraints support
  - Cleanup test-requirements
  - Updated from global requirements
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 2.23.0
  - Trivial: Remove testscenarios from test-requirements.txt
  - rearrange existing documentation to fit the new standard layout
  - Make the mock call in MemoryCacheTest forward-compatible
  - Remove log translations
  - Make sure host in maintenance mode excluded from image upload
  - Add hacking rule to prevent log translations
  - Wrong member variable name in class Datastore
  - Improve unit test coverage
  - Use https for references to openstack.org
  - Use request_handler() for ExtensionManager APIs
  - Update URLs in documents according to document migration
  - [Fix gate]Update test requirement
  - pbr.version.VersionInfo needs package name (oslo.xyz and not oslo_xyz)
  - Update reno for stable/ocata
  - Do not prune some special XML elements which are empty
  - Improving cover testenv
  - Improve logging for task updates
  - Updated from global requirements
  - Enable warning-is-error in doc build
  - Switch from oslosphinx to openstackdocstheme
  - Add in support for removeKey
- drop 0001-Make-the-mock-call-in-MemoryCacheTest-forward-compat.patch
  Applied upstream
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 2.17.0:
  - Pass connection timeout so that invoke_api will not wait forever
  - Update reno for stable/newton
  - Remove mox3 in test-requirement.txt
  - Add 'uncommitted' field to the 'Datastore' class
  - Update home page link in cfg file
  - Fix setting the SOAP headers for remote calls.
  - Add Constraints support
  - Remove some useless log messages
  - Trivial fixes to the usage doc
  - Show team and repo badges on README
  - Imported Translations from Zanata
  - Add operation ID for remote calls
  - Remove references to Python 3.4
  - Enable release notes translation
  - Set pool size for HTTPS connections
  - Fix image meta-data update for Glance v2
  - Files with no code must be left completely empty
  - Updated from global requirements
  - Add SPBM WSDL for vSphere 6.5
  - [TrivialFix] Replace 'assertTrue(a in b)' with 'assertIn(a, b)'
- Add 0001-Make-the-mock-call-in-MemoryCacheTest-forward-compat.patch
* Thu Sep  1 2016 tbechtold@suse.com
- update to version 2.14.0
  * Fix TypeError:six.StringIO(resp.content) must be str or None, not bytes.
  * Updated from global requirements
  * Method to download file to VMware server
* Wed Aug 10 2016 tbechtold@suse.com
- update to 2.12.0:
  * Updated from global requirements
  * Add http_method to download_stream_optimized_data
  * Refactor the image transfer
  * Remove discover from test-requirements
  * Add a py35 tox venv for upcoming py35 support
  * Remove unnecessary properties from image-meta
* Mon Aug  1 2016 tbechtold@suse.com
- update to 2.10.0:
  * Updated from global requirements
  * Imported Translations from Zanata
  * Refactor VmdkWriteHandle and VmdkReadHandle
  * Add reno for release notes management
  * Support download of virtual disk in ova container
  * Trivial: ignore openstack/common in flake8 exclude list
  * Should not raise Exception before connection close
  * Remove explicit use of asserts
  * Move bandit into pep8
- update _service and switch to upstream spec
* Fri Apr  1 2016 tbechtold@suse.com
- update to 2.5.0:
  * Updated from global requirements
  * Remove bandit.yaml in favor of defaults
  * Update translation setup
  * Imported Translations from Zanata
  * Use oslo_utils reflection to get function name
  * Python 3 deprecated the logger.warn method in favor of warning
  * Put py34 first in the env order of tox
  * assertIsNone(val) instead of assertEqual(None,val)
  * isoformat instead of deprecated timeutils.strtime
  * Overwrite VMwareDriverException message
  * Clean requirements
  * Trival: Remove 'MANIFEST.in'
  * Remove python 2.6 classifier
  * Remove python 2.6 and cleanup tox.ini
* Wed Oct 14 2015 tbechtold@suse.com
- update to 1.22:
  * Updated from global requirements
  * Fix coverage configuration and execution
  * No need for Oslo Incubator Sync
  * Add support for SSL thumbprint when using FileWriteHandle
  * Define WithRetrieval context
  * Imported Translations from Zanata
  * Add shields.io version/downloads links/badges into README.rst
  * docs - Set pbr 'warnerrors' option for doc build
  * clean up auto-doc api build
  * do not show the full release history in the main table of contents
  * clean up readme and documentation titles
  * Change ignore-errors to ignore_errors
  * Updated from global requirements
  * Add support for using HTTP POST in VmdkWriteHandle
  * Add unit tests for FileHandle._create_connection
  * Update the documentation
* Wed Sep  9 2015 tbechtold@suse.com
- update to 1.21.0:
  * Updated from global requirements
  * Use SSL thumbprints for NFC transfer
  * Update bandit.yaml to the latest
  * flake8 - remove unused rules
  * Imported Translations from Transifex
  * Allow http connection pool size to be configured
- Adjust Requires according to requirements.txt
* Fri Jul 31 2015 tbechtold@suse.com
- Unify spec file #2
- Remove conditionals for older SUSE versions
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file. Use fedora compatible files macros
* Tue Jul 28 2015 tbechtold@suse.com
- update to 1.18.0:
  * Make usage doc easier to understand for library consumers
  * Imported Translations from Transifex
  * Remove username from logs
  * Updated from global requirements
- update Requires according to requirements.txt
* Mon Jul 27 2015 dmueller@suse.com
- update to 1.17.0:
  * Update log level of session related logs
  * Fix mock calls
  * Updated from global requirements
  * Mask/truncate vCenter credentials in suds logs
  * Imported Translations from Transifex
  * Add tox target to find missing requirements
  * Updated from global requirements
  * Fix exception to string in py34
  * Updated from global requirements
* Thu Jun 25 2015 tbechtold@suse.com
- update to 0.15.1:
  * Add in support for ManagedObjectNotFound exception
  * Deprecate unused exceptions
  * Raise VimFaultException for unknown faults
  * Exception hierarchy refactoring
  * Update progress lease every 60 seconds
  * Fix bandit tox environment to properly run
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Mon Jun 22 2015 tbechtold@suse.com
- update to 0.14.0:
  * Remove oslo namespace package
  * Port test from Nova
  * Imported Translations from Transifex
* Mon Jun  1 2015 tbechtold@suse.com
- update to 0.13.1:
  * Imported Translations from Transifex
  * Revert "Raise VimFaultException for unknown faults"
  * Add ToolsUnavailable exception
  * Add support for dynamicProperty
  * Remove support for Python 3.3
  * Updated from global requirements
  * Remove run_cross_tests.sh
  * Use suds-jurko on Python 2
  * Updated from global requirements
  * Imported Translations from Transifex
  * Updated from global requirements
  * Raise VimFaultException for unknown faults
  * Imported Translations from Transifex
  * Add NoDiskSpaceException
  * Add utility function to get profiles by IDs
  * Add bandit to tox for security static analysis
  * Add SPBM WSDL for vSphere 6.0
- Adjust Requires according to requirements.txt
* Sat May 16 2015 dmueller@suse.com
- update to 0.12.0:
  * Uncap library requirements for liberty
  * Cleanup README.rst and setup.cfg
  * Update to latest hacking
  * Imported Translations from Transifex
  * Revert "VMWare NSXv: Common components"
  * Updated from global requirements
  * Move pylint dependency to tox.ini
  * Move exception related tests to new module
* Tue Apr  7 2015 tbechtold@suse.com
- update to 0.11.1:
  * Switch to non-namespaced module imports
  * Imported Translations from Transifex
  * Move missing tests to new oslo_vmware location
  * Imported Translations from Transifex
  * Add get_datastore_by_ref method to oslo.vmware
  * Change use of random to random.SystemRandom
* Mon Mar  2 2015 tbechtold@suse.com
- update to 0.10.0:
  * Imported Translations from Transifex
  * Updated from global requirements
  * Handle SPBM SecurityError
  * PBM utility method to retrieve profiles of a VM
  * Updated from global requirements
  * Imported Translations from Transifex
  * Add missing links to README
  * VMWare NSXv: Common components
- Adjust Requires according to requirements.txt
* Tue Feb 10 2015 dmueller@suse.com
- update to 0.9.0:
  * Imported Translations from Transifex
  * Updated from global requirements
  * Correct usage to oslo_vmware
  * Fix line wrapping
  * Correct the doc usage example
  * Fix missing project name in installation doc
  * Fix race during session creation
  * Make setup.cfg packages include oslo.vmware
  * Move files out of the namespace package
  * Use ToggleLazy fixture from oslo.i18n
  * Use _is_valid_ipv6 from oslo.utils
  * Allow checking api session
  * Add pbr to installation requirements
  * Update urllib3 requirements
  * Workflow documentation is now in infra-manual
  * Fix re-create session during transient failures
* Mon Jan  5 2015 dmueller@suse.com
- update to 0.8.0:
  * Switch to use requests/urllib3 and enable cacert validation
  * Updated from global requirements
  * Enable support for python 3.x
  * Imported Translations from Transifex
  * Activate pep8 check that _ is imported
  * Do not log when reraising an exception
  * Imported Translations from Transifex
  * Add unit test for VC 5.1 web fault handling
  * Fix to get exception detail with vCenter 5.1
  * Download image API to bypass vCenter
  * Enable the PBM WSDL to be updated
  * Support building wheels (PEP-427)
  * Fixup autoindex.rst only if it exists
  * Supress error logs when exception is thrown
  * Fix handling of fault details
  * Fix UnboundLocalError during WebFault handling
  * Use faultstring attribute in suds.WebFault.fault
  * Imported Translations from Transifex
  * Fix the log message for progress
  * Add API to get the entity inventory path
  * VimExceptions need to support i18n objects
  * Switch to using oslo.utils
  * Use custom transport adapter for file URLs
  * getText can be called only when doc is not None
  * Add unit test for suds cache expiration
  * Add a memory based shared cache
* Sat Sep 27 2014 dmueller@suse.com
- update to 0.6.0:
  * Add DuplicateName exception
  * Add 'details' property to VMwareDriverException
  * Enable oslo.i18n for oslo.vmware
  * Add API to enable calling module to register an exception
  * Imported Translations from Transifex
  * Add docs target and generate api docs
  * Updated from global requirements
  * Work toward Python 3.4 support and testing
  * warn against sorting requirements
  * Add exception for TaskInProgress
  * Updated from global requirements
  * Refactoring to reduce noise in log files
  * Imported Translations from Transifex
  * Add missing session parameter to get_summary
  * Updated from global requirements
  * Switch off caching to prevent cache poisoning by local attacker
  * Support for copying streamOptimized disk to file
  * Add support for the DatastoreURL object
  * Add methods to the Datastore objects
  * Imported Translations from Transifex
  * Add Pylint testenv environment
* Sun Aug 31 2014 dmueller@suse.com
- update to 0.5.0:
  * _trunc_id to check if the session_id is not None
  * Enabled hacking check H305
  * Imported Translations from Transifex
  * Add constant for ESX datacenter path (HTTP access)
  * Store PBM wsdl in the oslo.vmware git repository
  * Bump hacking to version 0.9.2
  * Add support for using extensions
  * The 'result' variable in RetryDecorator may be undefined
  * Imported Translations from Transifex
  * Fix docstrings of constructors
  * Do not log the full session ID
  * Refactor the PBM support
  * Fix wrong usage of assertRaises
  * Translations: make use of _LE, _LI and _LW
* Fri Jul 11 2014 dmueller@suse.com
- update to 0.4.0:
  * Sync excutils from Oslo
  * Updated from global requirements
  * Use assertIsNone
  * Bump hacking to 0.9.x series
  * replace iterator.next() with next(iterator)
  * remove definitions of Python Source Code Encoding
  * Setup for translation
  * Updated from global requirements
  * cleaning up index.rst file
  * Add networkFolder in the traversal spec
  * Ensure port support does not break backward compatibility
  * replace string format arguments with function parameters
  * Support for IPv6 and Non-standard ports
  * Support 'InvalidPowerState' exception
  * Don't translate debug level logs in oslo-vmware
  * Updated from global requirements
  * Sync changes from Nova error_util.py
  * Updated from global requirements
  * Remove __del__ usage in oslo.vmware driver
  * Add a test to oslo.vmware test_image_transfer
  * import run_cross_tests.sh from incubator
  * Fix vim25:InvalidRequest when no profiles exist
  * VMware: treat cases when SOAP reply does not have a body
  * Add unittest method "test_download_flat_image"
  * Add missing unit tests for VMwareAPISession
* Thu May 22 2014 dmueller@suse.com
- update to 0.3.0
* Fri Mar  7 2014 speilicke@suse.com
- Add python_requires source service
* Fri Mar  7 2014 speilicke@suse.com
- Initial version
